/**
 * Create an audio version of your posts, with a selection of 194 voices across 35+ languages and variants.
 * Exclusively on Envato Market: https://1.envato.market/speaker
 *
 * @encoding        UTF-8
 * @version         2.0.5
 * @copyright       Copyright (C) 2018 - 2019 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Alexander Khmelnitskiy (info@alexander.khmelnitskiy.ua), Dmitry Merkulov (dmitry@merkulov.design)
 * @support         dmitry@merkulov.design
 **/

( function ( $ ) {
    
    "use strict";
    
    jQuery( document ).ready( function () {
        
        /** Bulk Create Audio. */
        var to_process = [];
        var f_bulk = false;
        jQuery( '#doaction' ).on( 'click', function( e ) {
            /** Process only 'Create Audio' action. */
            if (jQuery('#bulk-action-selector-top').val() !== 'speaker') { return; }
            e.preventDefault();
            
            to_process = [];
            f_bulk = true;
            
            /** Generate Audio foreach post/page.  */
            jQuery( '#the-list .check-column input:checked' ).each( function() {                
                to_process.push( this.value );
            } );
            
            if ( ! to_process.length ) { return; }
            to_process = to_process.reverse();
            var p_id = to_process.pop();
            jQuery( '#post-' + p_id + ' .mdp-speaker-gen' ).click();
            jQuery( '#cb-select-' + p_id ).click();
            
        } );
            
        /** Individual Create Audio Button. */
        jQuery( document ).on( 'click', '.mdp-speaker-gen', function( e ) {

            var link = jQuery( this );
            var sel = link.parent();

            e.preventDefault();
            if ( link.hasClass( 'is-busy' ) ) { return; }
            
            /** Disable links. */
            sel.find( 'a' ).addClass( 'is-busy' ).attr( 'disabled', true );

            /** Remove Create Audio icon */
            link.find( 'img' ).remove();
            
            /** Current Post ID. */
            var post_id = jQuery( this ).data( 'post-id' );
            
            var data = {
                action: 'gspeak',
                security: mdp_speaker.ajax_nonce,
                post_id: post_id
            };
            
            jQuery.ajax( {
                type: 'POST',
                url: ajaxurl,
                data: data,
                success: function ( response ) {

                    /** Add audio player if audio file is ready. */
                    if( response.success ) {
                        sel.html( '<a href="' + mdp_speaker.audio_url + 'post-' + post_id + '.mp3' + '" download="" class="mdp-speaker-download"></a>' );
                        sel.append( '<a href="#" class="mdp-speaker-gen" data-post-id="' + post_id + '" style="display: none;"></a>' );
                    } else {
                    
                        /** Show Error message to user. */
                        show_err_msg( response );
                    }
                    
                    /** Call Next Ajax, if we have id's to process. */
                    if ( to_process.length ) {
                        var p_id = to_process.pop();
                        jQuery( '#post-' + p_id + ' .mdp-speaker-gen' ).click();
                        jQuery( '#cb-select-' + p_id ).click();
                    }else if ( f_bulk ) {
                        f_bulk = false;
                        alert( 'Generation of Audio Files is Complete.' );
                    }

                },
                fail: function( response ) {

                    sel.html( '<a href="#" class="mdp-speaker-error"></a>' );
                    
                    show_err_msg( response );
                    
                    /** Call Next Ajax, if we have id's to process. */
                    if ( to_process.length ) {
                        var p_id = to_process.pop();
                        jQuery( '#post-' + p_id + ' .mdp-speaker-gen' ).click();
                        jQuery( '#cb-select-' + p_id ).click();
                    }

                }
            } );
            
            /** Show Alert with Error. */
            function show_err_msg( err ) {
                
                console.log( err );
                
                if ( err.message ) {
                    alert( 'ERROR:\n ' + err.message );
                } else if ( err.responseText ) {
                    alert( 'ERROR:\n ' + err.responseText );
                } else {
                    alert( 'ERROR:\n ' + err );
                }
                
            }
            
        } ); // END Create Audio Button.
        
    } ); // END Document Ready.

} ( jQuery ) );