/**
 * Create an audio version of your posts, with a selection of 194 voices across 35+ languages and variants.
 * Exclusively on Envato Market: https://1.envato.market/speaker
 *
 * @encoding        UTF-8
 * @version         2.0.5
 * @copyright       Copyright (C) 2018 - 2019 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Alexander Khmelnitskiy (info@alexander.khmelnitskiy.ua), Dmitry Merkulov (dmitry@merkulov.design)
 * @support         dmitry@merkulov.design
 **/

( function ( $ ) {
    
    "use strict";
    
    $( document ).ready( function () {
        /** Show warning if we try to generate audio with unsaved changes. */
        let unsaved = false;
        
        /** For Gutenberg. */
        if (
            document.body.classList.contains( 'block-editor-page' )  &&
            !document.body.classList.contains( 'vc_editor' )
        ) {

            wp.data.subscribe( function () {
                if ( ! wp.data.select( 'core/editor' ) ) { return; }

                var isSavingPost = wp.data.select( 'core/editor' ).isSavingPost();
                var isAutosavingPost = wp.data.select( 'core/editor' ).isAutosavingPost();

                if ( isSavingPost && ! isAutosavingPost ) {

                    /** Post Saved First Time. */
                    if ( $( '.mdp-warning' ).length ) {
                        $( '.mdp-warning' ).replaceWith( '<div class="components-panel__row"><button id="mdp_speaker_generate" type="button" class="button-large components-button is-button is-primary is-large">Create audio</button></div>' );
                    }

                    unsaved = false;
                }

            } );
            
        }
        
        /** Triggers change in all input fields including text type. */
        $( ':input' ).on( 'change', function() { unsaved = true; } );
        
        /** Create Audio Button. */
        $( document ).on( 'click', '#mdp_speaker_generate', function() {
            
            if ( $( this ).hasClass( 'is-busy' ) ) { return; }
            
            /** For Gutenberg. */
            var gut_unsaved = false; // If there are unsaved changes.
            if ( document.body.classList.contains( 'block-editor-page' ) ) {
                if ( wp.data.select( 'core/editor' ) ) { 
                    if ( wp.data.select( 'core/editor' ).isEditedPostDirty() ) {
                        gut_unsaved = true;
                    }
                }
            }
            
            if ( unsaved || gut_unsaved ) {
                if ( ! confirm( 'It looks like you made changes and did not save it. Continue anyway?' ) ) {
                    return;
                }
            }
            
            /** Disable Button. */
            $( this ).addClass( 'is-busy' ).attr( 'disabled', true );
            
            var data = {
                action: 'gspeak',
                security: mdp_speaker.ajax_nonce,
                post_id: mdp_speaker.post_id
            };
            
            $.post( ajaxurl, data, function ( response ) {
                
                /** Add audio player if audio file is ready. */
                if ( response.success ) {
                    location.reload();
                } else {
                    
                    /** Show Error message to user. */
                    show_err_msg( response );
                }
                
            } )
            .fail( function( response ) {
                
                show_err_msg( response );
                
            } )
            .always( function() {
                
                /** Enable Button. */
                $( '#mdp_speaker_generate' ).removeClass( 'is-busy' ).attr( 'disabled', false );
                
            } );
            
            /** Show Alert with Error. */
            function show_err_msg( err ) {
                
                console.log( err );
                
                if ( err.message ) {
                    alert( 'ERROR:\n ' + err.message );
                } else if ( err.responseText ) {
                    alert( 'ERROR:\n ' + err.responseText );
                } else {
                    alert( 'ERROR:\n ' + err );
                }
                
            }
            
        } );

        /** Remove Audio Button. */
        $( document ).on( 'click', '#mdp_speaker_remove', function() {
            
            if ( $( this ).hasClass( 'is-busy' ) ) { return; }
            
            /** Confirm deteting. */
            if ( ! confirm( 'Are you sure you want to delete the audio version of this post?' ) ) { return; }
            
            /** Disable Button. */
            $( this ).addClass( 'is-busy' ).attr( 'disabled', true );
            
            var data = {
                action: 'remove_audio',
                security: mdp_speaker.ajax_nonce,
                post_id: mdp_speaker.post_id
            };
            
            $.post( ajaxurl, data, function ( response ) {
                
                /** Add audio player if audio file is ready. */
                if( response == 'ok' ) {
                    location.reload();
                }
                
            } )
            .fail( function() {
                alert( "error" );
            } )
            .always( function() {
                
                /** Enable Button. */
                $( '#mdp_speaker_generate' ).removeClass( 'is-busy' ).attr( 'disabled', false );
            } );
            
        } );
        
        
    } );

} ( jQuery ) );
