/**
 * Create an audio version of your posts, with a selection of 194 voices across 35+ languages and variants.
 * Exclusively on Envato Market: https://1.envato.market/speaker
 *
 * @encoding        UTF-8
 * @version         2.0.5
 * @copyright       Copyright (C) 2018 - 2019 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Alexander Khmelnitskiy (info@alexander.khmelnitskiy.ua), Dmitry Merkulov (dmitry@merkulov.design)
 * @support         dmitry@merkulov.design
 **/

( function ( $ ) {
    
    "use strict";
    
    $( document ).ready( function () {

        /** Make table great again! */
        $( '#mdp-speaker-settings-language-tbl' ).removeClass('hidden');
        var lang_table = $( '#mdp-speaker-settings-language-tbl' ).DataTable( {

            /** Show entries. */
            lengthMenu: [ [-1], ["All"] ],
            
            /** Add filters to table footer. */
            initComplete: function () {
                this.api().columns().every(function () {
                    var column = this;
                    var uiSelect = $( '<div class="mdc-select mdc-select-width mdc-select--outlined mdp-language-select"><i class="mdc-select__dropdown-icon"></i></div>' );
                    var select = $( '<select class="mdc-select__native-control"><option value="" selected>Select Language</option></select>' );
                    var uiNotched = $( '<div class="mdc-notched-outline"><div class="mdc-notched-outline__leading"></div><div class="mdc-notched-outline__notch"><label class="mdc-floating-label mdc-floating-label--float-above">Select language</label></div><div class="mdc-notched-outline__trailing"></div></div>' );

                    /** Create filter only for first column. */
                    if ( column[0][0] != 0 ) { return; }

                    uiSelect.prependTo( '#mdp-speaker-settings-language-select' );
                    select.appendTo( '.mdp-language-select' );
                    uiNotched.appendTo( '.mdp-language-select' );

                    select.on( 'change', function () {

                        $( '#mdp-speaker-settings-language-tbl tbody' ).show();
                        $( '#mdp-speaker-settings-language-tbl_info' ).show();
                        $( '#mdp-speaker-settings-language-tbl_paginate' ).hide();
                        $( '#mdp-speaker-settings-language-tbl_length' ).hide();
                        $( '#mdp-speaker-settings-language-tbl thead' ).show();

                        var val = $.fn.dataTable.util.escapeRegex( $(this).val() );
                        column.search( val ? '^' + val + '$' : '', true, false ).draw();
                    } );

                    column.data().unique().sort().each( function ( d, j ) {
                        select.append( '<option value="' + d + '">' + d + '</option>' );
                    } );
                } );

                // Hide all lines on first load.
                $( '#mdp-speaker-settings-language-tbl tbody' ).hide();
                $( '#mdp-speaker-settings-language-tbl_info' ).hide();
                $( '#mdp-speaker-settings-language-tbl_paginate' ).hide();
                $( '#mdp-speaker-settings-language-tbl_length' ).hide();
                $( '#mdp-speaker-settings-language-tbl thead' ).hide();
            }
        } );
        
        /** Select language. */
        $( '#mdp-speaker-settings-language-tbl tbody' ).on( 'click', 'tr', function ( e ) {
            $( '#mdp-speaker-settings-language-tbl tr.selected' ).removeClass( 'selected' );
            $( this ).addClass( 'selected' );

            var voice_name = $( '#mdp-speaker-settings-language-tbl tr.selected .mdp-voice-name' ).attr("title");
            var lang_code = $( '#mdp-speaker-settings-language-tbl tr.selected .mdp-lang-code' ).text();
            $( '.mdp-now-used strong' ).html( voice_name );
            $( '#mdp-speaker-settings-language' ).val( voice_name );
            $( '#mdp-speaker-settings-language-code' ).val( lang_code );

            // Update Audio Sample.
            var audio = $( '.mdp-now-used audio' );
            $( '.mdp-now-used audio source' ).attr( 'src', 'https://cloud.google.com/text-to-speech/docs/audio/' + voice_name + '.mp3' );
            audio[0].pause();
            audio[0].load();
        } );
        
        /** The "Select Key File" button. */
        $( '.mdp-select-key-file-btn' ).on( 'click', function( e ) {
            e.preventDefault();
            var button = $( this );
            var key_uploader = wp.media({
                title: 'Select or Upload API Key File',
                button: {
                    text: 'Use this API Key'
                },
                library: {
                    type: [ 'json', 'text' ]
                },
                multiple: false  // Select only one file.
            })
            .on('select', function() {
                var attachment = key_uploader.state().get('selection').first().toJSON();
                $( button ).prev().val( attachment.id );
                $( button ).next().text( attachment.filename );
            })
            .open();
        });
        
    } );

} ( jQuery ) );
